@@ -42,7 +42,7 @@ class MainWindow(QtGui.QMainWindow):
             self.falschsound="/opt/quizzynator/falsch.wav"
             self.gameoversound="/opt/quizzynator/gameover.wav"
             self.rankupsound="/opt/quizzynator/rankup.wav"
-			self.savegame="/home/user/MyDocs/.Quizzynator/quizzynator.db"
+	    self.savegame="/home/user/MyDocs/.Quizzynator/quizzynator.db"
            
             #self.fragenkatalog="/home/user/MyDocs//fragenkatalog.py"      
             self.highscoredatenbank="/home/user/MyDocs/.QuizzyNator/highscores.db"
@@ -92,10 +92,10 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.back_2.clicked.connect(self.back_2)
         self.ui.back_3.clicked.connect(self.back_2)
         self.ui.back_4.clicked.connect(self.back_2)
-        self.ui.updater.clicked.connect(self.update)
-        self.ui.search.clicked.connect(self.search)
+  
+      
         self.ui.sound.toggled.connect(self.sound)
-        self.ui.start_update.clicked.connect(self.updating)
+  
         self.ui.vollbild.toggled.connect(self.vollbild)
         self.ui.hochformat.toggled.connect(self.format)
         self.ui.nextquest.clicked.connect(self.choose_frage)
